==> java-client-2.2.5-sources.jar: com/couchbase/client/java/query/dsl/path/index/DefaultCreateIndexPath.java <==
/**
 * Copyright (C) 2015 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.java.query.dsl.path.index;

import com.couchbase.client.core.annotations.InterfaceAudience;
import com.couchbase.client.core.annotations.InterfaceStability;
import com.couchbase.client.java.query.dsl.element.IndexElement;
import com.couchbase.client.java.query.dsl.path.AbstractPath;

/**
 * See {@link CreateIndexPath}.
 *
 * @author Simon Baslé
 * @since 2.2
 */
@InterfaceStability.Experimental
@InterfaceAudience.Private
public class DefaultCreateIndexPath extends AbstractPath implements CreateIndexPath {

    public DefaultCreateIndexPath() {
        super(null);
    }

    @Override
    public OnPath create(String indexName) {
        element(new IndexElement(indexName));
        return new DefaultOnPath(this);
    }

    @Override
    public OnPrimaryPath createPrimary() {
        element(new IndexElement());
        return new DefaultOnPrimaryPath(this);
    }
}

==> java-client-2.2.8-sources.jar: com/couchbase/client/java/query/dsl/path/index/DefaultCreateIndexPath.java <==
/**
 * Copyright (C) 2015 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.java.query.dsl.path.index;

import com.couchbase.client.core.annotations.InterfaceAudience;
import com.couchbase.client.core.annotations.InterfaceStability;
import com.couchbase.client.java.query.dsl.element.IndexElement;
import com.couchbase.client.java.query.dsl.path.AbstractPath;

/**
 * See {@link CreateIndexPath}.
 *
 * @author Simon Baslé
 * @since 2.2
 */
@InterfaceStability.Experimental
@InterfaceAudience.Private
public class DefaultCreateIndexPath extends AbstractPath implements CreateIndexPath {

    public DefaultCreateIndexPath() {
        super(null);
    }

    @Override
    public OnPath create(String indexName) {
        element(new IndexElement(indexName));
        return new DefaultOnPath(this);
    }

    @Override
    public OnPrimaryPath createPrimary() {
        element(new IndexElement());
        return new DefaultOnPrimaryPath(this);
    }

    @Override
    public OnPrimaryPath createPrimary(String customPrimaryName) {
        element(new IndexElement(customPrimaryName, true));
        return new DefaultOnPrimaryPath(this);
    }
}
